@@ -4,6 +4,7 @@ for x in $(cat /proc/cmdline); do
         case ${x} in
                 m_bpp=*) export bpp=${x#*=} ;;
                 hdmimode=*) export mode=${x#*=} ;;
+		modeline=*) export modeline=${x#*=} ;;
         esac
 done
 
@@ -12,7 +13,9 @@ DISP_CAP=/sys/class/amhdmitx/amhdmitx0/disp_cap
 DISP_MODE=/sys/class/display/mode
 
 # if setenv nographics "1" in boot.ini then this needs to fail
-[[ -f $DISP_MODE ]] || exit 0
+if [ ! -f $DISP_MODE ]; then
+	exit 0
+fi
 
 echo $mode > $DISP_MODE
 
@@ -31,6 +34,10 @@ common_display_setup() {
 }
 
 case $mode in
+		custombuilt*)
+			export X=`echo $modeline | cut -f1 -d","`
+			export Y=`echo $modeline | cut -f2 -d","`
+			;;
 		480*) 
 			export X=720 
 			export Y=480 
